==> nextcloud-15.0.10.tar.bz2: nextcloud/apps/updatenotification/l10n/eo.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} disponeblas. Ekhavi pli da informo pri kiel ĝisdatigi.",
    "Update notifications" : "Sciigoj pri ĝisdatigoj",
    "Channel updated" : "Kanalo ĝisdatigita",
    "The update server could not be reached since %d days to check for new updates." : "La servilo de ĝisdatigoj ne atingeblis de %d tagoj.",
    "Please check the Nextcloud and server log files for errors." : "Bv. kontroli la protokoldosieron de Nextcloud kaj de la servilo pri eraroj.",
    "Update to %1$s is available." : "Ĝisdatigo al %1$s disponeblas.",
    "Update for %1$s to version %2$s is available." : "Ĝisdatigo de %1$s al versio %2$s disponeblas.",
    "Update for {app} to version %s is available." : "Ĝisdatigo de {app} al versio %s disponeblas.",
    "Update notification" : "Sciigo pri ĝisdatigoj",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Montras sciigojn pri ĝisdatigoj pri Nextcloud kaj provizas ununuran ensaluton („SSO“ angle) por la ĝisdatigilo.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versio, kiun vi nun uzas, ne plus estas subtenata. Bv. ĝisdatigi al subtenata versio kiel eble plej rapide.",
    "Apps missing updates" : "Aplikaĵoj kun mankantaj ĝisdatigoj",
    "View in store" : "Vidi en la aplikaĵejo",
    "Apps with available updates" : "Apikaĵoj kun disponeblaj ĝisdatigoj",
    "Open updater" : "Malfermi la ĝisdatigilon",
    "Download now" : "Elŝuti nun",
    "What's new?" : "Kio nova?",
    "The update check is not yet finished. Please refresh the page." : "La kontrolo pri ĝisdatigoj ankoraŭ ne finiĝis. Bv. aktualigi la paĝon.",
    "Your version is up to date." : "Via versio estas ĝisdata.",
    "A non-default update server is in use to be checked for updates:" : "Nedefaŭlta servilo por ĝisdatigoj uziĝas por kontroli ĝisdatigojn:",
    "Update channel:" : "Ĝisdatiga kanalo:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Vi povas ĝisdatigi iam ajn al pli nova versio. Sed vi povas neniam malĝisdatigi al pli stabila versio.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Rimarku, ke, post nova eldono, necesos iom da tempo, antaŭ ol ĝi montriĝos ĉi tie. Ni eldonas novajn versiojn laŭgrade al niaj uzantoj, kaj ni kelkfoje preterlasas version, kiam oni trovas problemojn.",
    "Notify members of the following groups about available updates:" : "Sciigi anojn de la jenaj grupoj pri disponeblaj ĝisdatigoj:",
    "Only notification for app updates are available." : "Nur sciigoj pri aplikaĵaj ĝisdatigoj disponeblas.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "La elektita kanalo pri ĝisdatigoj igas la dediĉitajn sciigojn por la servilo neutilaj.",
    "The selected update channel does not support updates of the server." : "La elektita ĝisdatiga kanalo ne subtenas ĝisdatigojn de la servilo.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Nova versio disponeblas: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Kontrolita je {lastCheckedDate}",
    "Checking apps for compatible updates" : "Kontrolado de aplikaĵoj pri kongruaj ĝisdatigoj",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Bv. certigi, ke via dosiero „config.php“ ne agordas <samp>appstoreenabled</samp> al malvero („false“).",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Ne eblis konektiĝi al aplikaĵejo, aŭ la aplikaĵejo sendis neniun ĝisdatigojn. Serĉu permane pri ĝisdatigoj, aŭ certigu, ke via servilo povas aliri al la interreto kaj povas konektiĝi al la aplikaĵejo.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Ĉiuj</strong> aplikaĵoj havas ĝisdatigon por tiu ĉi versio",
    "View changelog" : "Vidi ŝanĝoprotokolon",
    "Stable" : "Stabila",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La plej freŝa stabila versio. Ĝi taŭgas por ĉiutaga uzo, kaj ĝi ĝisdatiĝos ĉiufoje al la lasta ĉefversio.",
    "Production" : "Produktado",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Ĝi uzas ĉiam la plej freŝan flikaĵon, sed ĝi ne tuj ĝisdatiĝos al la sekva ĉefversio. Transiro al la sekva ĉefversio okazos laŭ la dua neĉefa eldono (x.0.2), kaj nur se tiu servilo jam uzas la lastan neĉefan version.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Antaŭeldona versio nur por testi novajn trajtojn; ne taŭgas por produktada medio.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplikaĵo havas neniun ĝisdatigon por tiu versio","<strong>%n</strong> aplikaĵoj havas neniun ĝisdatigon por tiu versio"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Vi povas ĝisdatigi iam ajn al pli nova aŭ eksperimenta kanalo. Sed vi povas neniam malĝisdatigi al pli stabila kanalo.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>Produktado</strong> uzas ĉiam la plej freŝan flikaĵon, sed ĝi ne tuj ĝisdatiĝos al la sekva ĉefversio. Transiro al la sekva ĉefversio okazos laŭ la dua neĉefa eldono (x.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>Stabila</strong> estas la plej freŝa stabila versio. Ĝi taŭgas por ĉiutaga uzo, kaj ĝi ĝisdatiĝos ĉiufoje al la lasta ĉefversio.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>Beta</strong> estas antaŭeldona versio nur por testi novajn trajtojn; ĝi ne taŭgas por produktada medio.",
    "Could not start updater, please try the manual update" : "Ne eblis ruli la ĝisdatigilon, bv. provi mane ĝisdatigi."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.11.tar.bz2: nextcloud/apps/updatenotification/l10n/eo.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} disponeblas. Ekhavi pli da informo pri kiel ĝisdatigi.",
    "Channel updated" : "Kanalo ĝisdatigita",
    "Update notifications" : "Sciigoj pri ĝisdatigoj",
    "The update server could not be reached since %d days to check for new updates." : "La servilo de ĝisdatigoj ne atingeblis de %d tagoj.",
    "Please check the Nextcloud and server log files for errors." : "Bv. kontroli la protokoldosieron de Nextcloud kaj de la servilo pri eraroj.",
    "Update to %1$s is available." : "Ĝisdatigo al %1$s disponeblas.",
    "Update for %1$s to version %2$s is available." : "Ĝisdatigo de %1$s al versio %2$s disponeblas.",
    "Update for {app} to version %s is available." : "Ĝisdatigo de {app} al versio %s disponeblas.",
    "Update notification" : "Sciigo pri ĝisdatigoj",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Montras sciigojn pri ĝisdatigoj pri Nextcloud kaj provizas ununuran ensaluton („SSO“ angle) por la ĝisdatigilo.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versio, kiun vi nun uzas, ne plus estas subtenata. Bv. ĝisdatigi al subtenata versio kiel eble plej rapide.",
    "Apps missing updates" : "Aplikaĵoj kun mankantaj ĝisdatigoj",
    "View in store" : "Vidi en la aplikaĵejo",
    "Apps with available updates" : "Apikaĵoj kun disponeblaj ĝisdatigoj",
    "Open updater" : "Malfermi la ĝisdatigilon",
    "Download now" : "Elŝuti nun",
    "What's new?" : "Kio nova?",
    "The update check is not yet finished. Please refresh the page." : "La kontrolo pri ĝisdatigoj ankoraŭ ne finiĝis. Bv. aktualigi la paĝon.",
    "Your version is up to date." : "Via versio estas ĝisdata.",
    "A non-default update server is in use to be checked for updates:" : "Nedefaŭlta servilo por ĝisdatigoj uziĝas por kontroli ĝisdatigojn:",
    "Update channel:" : "Ĝisdatiga kanalo:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Vi povas ĝisdatigi iam ajn al pli nova versio. Sed vi povas neniam malĝisdatigi al pli stabila versio.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Rimarku, ke, post nova eldono, necesos iom da tempo, antaŭ ol ĝi montriĝos ĉi tie. Ni eldonas novajn versiojn laŭgrade al niaj uzantoj, kaj ni kelkfoje preterlasas version, kiam oni trovas problemojn.",
    "Notify members of the following groups about available updates:" : "Sciigi anojn de la jenaj grupoj pri disponeblaj ĝisdatigoj:",
    "Only notification for app updates are available." : "Nur sciigoj pri aplikaĵaj ĝisdatigoj disponeblas.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "La elektita kanalo pri ĝisdatigoj igas la dediĉitajn sciigojn por la servilo neutilaj.",
    "The selected update channel does not support updates of the server." : "La elektita ĝisdatiga kanalo ne subtenas ĝisdatigojn de la servilo.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Nova versio disponeblas: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Kontrolita je {lastCheckedDate}",
    "Checking apps for compatible updates" : "Kontrolado de aplikaĵoj pri kongruaj ĝisdatigoj",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Bv. certigi, ke via dosiero „config.php“ ne agordas <samp>appstoreenabled</samp> al malvero („false“).",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Ne eblis konektiĝi al aplikaĵejo, aŭ la aplikaĵejo sendis neniun ĝisdatigojn. Serĉu permane pri ĝisdatigoj, aŭ certigu, ke via servilo povas aliri al la interreto kaj povas konektiĝi al la aplikaĵejo.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Ĉiuj</strong> aplikaĵoj havas ĝisdatigon por tiu ĉi versio",
    "View changelog" : "Vidi ŝanĝoprotokolon",
    "Stable" : "Stabila",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La plej freŝa stabila versio. Ĝi taŭgas por ĉiutaga uzo, kaj ĝi ĝisdatiĝos ĉiufoje al la lasta ĉefversio.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Antaŭeldona versio nur por testi novajn trajtojn; ne taŭgas por produktada medio.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplikaĵo havas neniun ĝisdatigon por tiu versio","<strong>%n</strong> aplikaĵoj havas neniun ĝisdatigon por tiu versio"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Vi povas ĝisdatigi iam ajn al pli nova aŭ eksperimenta kanalo. Sed vi povas neniam malĝisdatigi al pli stabila kanalo.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>Produktado</strong> uzas ĉiam la plej freŝan flikaĵon, sed ĝi ne tuj ĝisdatiĝos al la sekva ĉefversio. Transiro al la sekva ĉefversio okazos laŭ la dua neĉefa eldono (x.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>Stabila</strong> estas la plej freŝa stabila versio. Ĝi taŭgas por ĉiutaga uzo, kaj ĝi ĝisdatiĝos ĉiufoje al la lasta ĉefversio.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>Beta</strong> estas antaŭeldona versio nur por testi novajn trajtojn; ĝi ne taŭgas por produktada medio.",
    "Could not start updater, please try the manual update" : "Ne eblis ruli la ĝisdatigilon, bv. provi mane ĝisdatigi.",
    "Production" : "Produktado",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Ĝi uzas ĉiam la plej freŝan flikaĵon, sed ĝi ne tuj ĝisdatiĝos al la sekva ĉefversio. Transiro al la sekva ĉefversio okazos laŭ la dua neĉefa eldono (x.0.2), kaj nur se tiu servilo jam uzas la lastan neĉefan version."
},
"nplurals=2; plural=(n != 1);");
